# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`kmod`](#kmod): Ensures a couple of mandatory files are present before managing their content.

### Defined types

* [`kmod::alias`](#kmod--alias): Manage kernel module aliases
* [`kmod::blacklist`](#kmod--blacklist): Set a kernel module as blacklisted.
* [`kmod::install`](#kmod--install): Set a kernel module as installed
* [`kmod::load`](#kmod--load): Manage a kernel module in /etc/modules.
* [`kmod::option`](#kmod--option): Manage kernel module options
* [`kmod::setting`](#kmod--setting): Manage kernel module settings

## Classes

### <a name="kmod"></a>`kmod`

Ensures a couple of mandatory files are present before managing their content.

#### Examples

##### 

```puppet
include kmod
```

#### Parameters

The following parameters are available in the `kmod` class:

* [`list_of_aliases`](#-kmod--list_of_aliases)
* [`list_of_blacklists`](#-kmod--list_of_blacklists)
* [`list_of_installs`](#-kmod--list_of_installs)
* [`list_of_loads`](#-kmod--list_of_loads)
* [`list_of_options`](#-kmod--list_of_options)
* [`owner`](#-kmod--owner)
* [`group`](#-kmod--group)
* [`directory_mode`](#-kmod--directory_mode)
* [`file_mode`](#-kmod--file_mode)
* [`exe_mode`](#-kmod--exe_mode)
* [`modprobe_d`](#-kmod--modprobe_d)
* [`modprobe_d_files`](#-kmod--modprobe_d_files)

##### <a name="-kmod--list_of_aliases"></a>`list_of_aliases`

Data type: `Hash`

Hash of [`kmod::alias`](#kmodalias) resources

Default value: `{}`

##### <a name="-kmod--list_of_blacklists"></a>`list_of_blacklists`

Data type: `Hash`

Hash of [`kmod::blacklist`](#kmodblacklist) resources

Default value: `{}`

##### <a name="-kmod--list_of_installs"></a>`list_of_installs`

Data type: `Hash`

Hash of [`kmod::install`](#kmodinstall) resources

Default value: `{}`

##### <a name="-kmod--list_of_loads"></a>`list_of_loads`

Data type: `Hash`

Hash of [`kmod::load`](#kmodload) resources

Default value: `{}`

##### <a name="-kmod--list_of_options"></a>`list_of_options`

Data type: `Hash`

Hash of [`kmod::option`](#kmodoption) resources

Default value: `{}`

##### <a name="-kmod--owner"></a>`owner`

Data type: `String[1]`

Default owner for all files (set via Hiera to allow defaults on all defined types)

Default value: `'root'`

##### <a name="-kmod--group"></a>`group`

Data type: `String[1]`

Default group for all files (set via Hiera to allow defaults on all defined types)

Default value: `'root'`

##### <a name="-kmod--directory_mode"></a>`directory_mode`

Data type: `Stdlib::Filemode`

Default mode for all directories (set via Hiera to allow defaults on all defined types)

Default value: `'0755'`

##### <a name="-kmod--file_mode"></a>`file_mode`

Data type: `Stdlib::Filemode`

Default mode for all regular files (set via Hiera to allow defaults on all defined types)

Default value: `'0644'`

##### <a name="-kmod--exe_mode"></a>`exe_mode`

Data type: `Stdlib::Filemode`

Default mode for all executable files (set via Hiera to allow defaults on all defined types)

Default value: `'0755'`

##### <a name="-kmod--modprobe_d"></a>`modprobe_d`

Data type: `Stdlib::Unixpath`

Location of `modprobe.d` directory

Default value: `'/etc/modprobe.d'`

##### <a name="-kmod--modprobe_d_files"></a>`modprobe_d_files`

Data type: `Array[Stdlib::Unixpath]`

Default files to create in `modprobe.d` directory

Default value:

```puppet
[
    '/etc/modprobe.d/modprobe.conf',
    '/etc/modprobe.d/aliases.conf',
    '/etc/modprobe.d/blacklist.conf',
  ]
```

## Defined types

### <a name="kmod--alias"></a>`kmod::alias`

Manage kernel module aliases

#### Examples

##### 

```puppet
kmod::alias { 'bond0':
  source => 'bonding',
}
```

#### Parameters

The following parameters are available in the `kmod::alias` defined type:

* [`source`](#-kmod--alias--source)
* [`ensure`](#-kmod--alias--ensure)
* [`file`](#-kmod--alias--file)
* [`aliasname`](#-kmod--alias--aliasname)

##### <a name="-kmod--alias--source"></a>`source`

Data type: `String[1]`

Name of the module to alias

##### <a name="-kmod--alias--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State of the alias

Default value: `'present'`

##### <a name="-kmod--alias--file"></a>`file`

Data type: `Stdlib::Unixpath`

File to manage

Default value: `"/etc/modprobe.d/${name}.conf"`

##### <a name="-kmod--alias--aliasname"></a>`aliasname`

Data type: `String[1]`

Name of the alias (defaults to the resource title)

Default value: `$name`

### <a name="kmod--blacklist"></a>`kmod::blacklist`

Set a kernel module as blacklisted.

#### Examples

##### 

```puppet
kmod::blacklist { 'pcspkr': }
```

#### Parameters

The following parameters are available in the `kmod::blacklist` defined type:

* [`ensure`](#-kmod--blacklist--ensure)
* [`file`](#-kmod--blacklist--file)

##### <a name="-kmod--blacklist--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State of the setting

Default value: `'present'`

##### <a name="-kmod--blacklist--file"></a>`file`

Data type: `Stdlib::Unixpath`

File to manage

Default value: `'/etc/modprobe.d/blacklist.conf'`

### <a name="kmod--install"></a>`kmod::install`

Set a kernel module as installed

#### Examples

##### 

```puppet
kmod::install { 'pcspkr': }
```

#### Parameters

The following parameters are available in the `kmod::install` defined type:

* [`ensure`](#-kmod--install--ensure)
* [`command`](#-kmod--install--command)
* [`file`](#-kmod--install--file)

##### <a name="-kmod--install--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State of the setting

Default value: `'present'`

##### <a name="-kmod--install--command"></a>`command`

Data type: `String[1]`

Command associated with the kernel module

Default value: `'/bin/true'`

##### <a name="-kmod--install--file"></a>`file`

Data type: `Stdlib::Unixpath`

File where the stanza is written

Default value: `"/etc/modprobe.d/${name}.conf"`

### <a name="kmod--load"></a>`kmod::load`

Manage a kernel module in /etc/modules.

#### Examples

##### 

```puppet
kmod::load { 'sha256': }
```

#### Parameters

The following parameters are available in the `kmod::load` defined type:

* [`ensure`](#-kmod--load--ensure)

##### <a name="-kmod--load--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State of the setting

Default value: `'present'`

### <a name="kmod--option"></a>`kmod::option`

Manage kernel module options

#### Examples

##### 

```puppet
kmod::option { 'bond0 mode':
  module  => 'bond0',
  option  => 'mode',
  value   => '1',
}
```

#### Parameters

The following parameters are available in the `kmod::option` defined type:

* [`option`](#-kmod--option--option)
* [`value`](#-kmod--option--value)
* [`module`](#-kmod--option--module)
* [`ensure`](#-kmod--option--ensure)
* [`file`](#-kmod--option--file)

##### <a name="-kmod--option--option"></a>`option`

Data type: `String[1]`

Option to manage

##### <a name="-kmod--option--value"></a>`value`

Data type: `Scalar`

Value of kernel module option

##### <a name="-kmod--option--module"></a>`module`

Data type: `String[1]`

Kernel module to manage

Default value: `$name`

##### <a name="-kmod--option--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State of the option

Default value: `'present'`

##### <a name="-kmod--option--file"></a>`file`

Data type: `Stdlib::Unixpath`

File to manage

Default value: `"/etc/modprobe.d/${module}.conf"`

### <a name="kmod--setting"></a>`kmod::setting`

Manage kernel module settings

#### Examples

##### 

```puppet
kmod__setting { 'kmod::option bond0 mode':
  ensure   => 'present',
  module   => 'bond0',
  category => 'options',
  file     => '/etc/modprobe.d/bond0.conf',
  option   => 'mode',
  value    => '1',
}
```

#### Parameters

The following parameters are available in the `kmod::setting` defined type:

* [`file`](#-kmod--setting--file)
* [`category`](#-kmod--setting--category)
* [`option`](#-kmod--setting--option)
* [`value`](#-kmod--setting--value)
* [`module`](#-kmod--setting--module)
* [`ensure`](#-kmod--setting--ensure)

##### <a name="-kmod--setting--file"></a>`file`

Data type: `Stdlib::Unixpath`

File to manage

##### <a name="-kmod--setting--category"></a>`category`

Data type: `String[1]`

Setting type

##### <a name="-kmod--setting--option"></a>`option`

Data type: `Optional[String]`

Key to manage

Default value: `undef`

##### <a name="-kmod--setting--value"></a>`value`

Data type: `Optional[Scalar]`

Value to manage

Default value: `undef`

##### <a name="-kmod--setting--module"></a>`module`

Data type: `String[1]`

Module to manage

Default value: `$name`

##### <a name="-kmod--setting--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

State of the setting

Default value: `'present'`

